//Globale variables
app.getSharedData().changeLanguage = false;
app.getSharedData().strings = "";

var form = app.getForm("F_Form1");

/**
* Returns the "str" attribute from the provided list for the specified language.
* In this case the list object is an object array like:
*
* [{"lang": "English", "str":"Name"},{"lang": "French", "str":"Nom"},{"lang": "Spanish", "str":"Nombre"}]
*
* theList: the list object
* theLang: the language to return, it must match the string in the "lang" attribute
*
* return: the value of the "str" attribute
*/
app.getSharedData().getLangStr = function(theList, theLang) {
  var str = "";
  for(var i=0;i<theList.length;i++) {
    var curItem = get(theList,i);
    if(curItem.lang === theLang) {
      str = curItem.str;
      break;
    }
  }
  return str;
}

/**
* Function that is responsible for changing the label of every item on the form.
* It loops through all the items defined in the app.getSharedData().strings array
* and changes the label if the items it finds.
*
* The strings array must be in the format:
* { "pageID":"" , "fieldID":"", "type":"", "langList":[{"lang": "E", "str":""},{"lang": "F", "str":""},] }
*
* Does not return anything, it changes the form items directly
*/
app.getSharedData().setLanguage = function(lang) {

  //loop through array and set each item to appropriate label
  for(var i=0; i< app.getSharedData().strings.length;i++) {
    //get item details to determine what to do
    var tempRow = get(app.getSharedData().strings, i);
    var theType = tempRow.type;
    var thePID = tempRow.pageID;
    var theFID = tempRow.fieldID;
    var theStr = "";    
    var theIndex = tempRow.index;

    theStr = app.getSharedData().getLangStr(tempRow.langList, lang); 
    get(form.getPage(thePID),theFID).setTitle(theStr);
    if(theType === "button") {
    	debugger;
      get(form.getPage(thePID),theFID).setContent(theStr);
    } else if(theType === "tabbedFolder") {
    	debugger;
    	//get(form.getPage(thePID),theFID).setSelectedTab(theStr);
    	app.getSharedData().changeTabLabel(get(form.getPage(thePID),theFID), theIndex, theStr);
    } else if(theType === "section") {
      app.getSharedData().changeSectionTitle(get(form.getPage(thePID),theFID), theStr);
    } else if(theType === "surveyHeader") {
    	var theIndex = tempRow.index;
      app.getSharedData().changeSurveyColumnHeaders(thePID, theFID, form.getId() + "-" + thePID + "-" + theFID, theIndex, theStr);
    } else if(theType === "pageNavigator")  {
      app.getSharedData().changeNavButtonLabels(get(form.getPage(thePID),theFID), theIndex, theStr);
    }
  }

  //reset flag back to off
  app.getSharedData().changeLanguage = false;
}

/**
* Returns the ID used in the HTML for the specified item by querying the "__widget" object.
*
* itemID: The item object (i.e. page.F_SingleLine)
*/
app.getSharedData().getFEBObjectID = function(itemObj) {
	
  var s = "";
  
  s = s + get(itemObj, "__widget");
  var a = s.split(",");
  var itemID = get(a, 1); //gets the widget ID
  
  //used for debugging
  form.getBO().F_debug.setValue(s);

  //trim whitespace
  itemID = itemID.substring(1, itemID.length - 1);
  
  return itemID;
}

/**
* Function used to change the label of a button
*
* buttonID: the ID of the section
* btnType: "next" or "previous"
* newString: the new string to use
*/
app.getSharedData().changeNavButtonLabels = function(buttonID, btnType, newString) {
  //gets the FEB dojo object
  var w = get(buttonID, "__widget");

  if(btnType === "next") {
  	//this is what gets set when you mouseover the button
  	w.nextLabel = newString;
  	//changes the label
  	w.nextButton.setLabel(newString);  	
  	//set the hover help
  	w.nextButtonTextContentNode.title = newString;
  } else if(btnType === "previous") {
  	w.backLabel = newString;
  	w.backButton.setLabel(newString);
  	w.backButtonTextContentNode.title = newString;
  }
}

/**
* Function used to change the label of a tab
*
* Note: Because this is undocumented, if the HTML changes in future releases then it
* will potentially break this function.
*
* sectionID: the ID of the section
* tab index: the index of the tab to change (starts at 0)
* newString: the new string to use
*/
app.getSharedData().changeTabLabel = function(tabID, tabIndex, newString) {

  // gets pointer to the outer div for the section
  var tabHTML = document.getElementById(app.getSharedData().getFEBObjectID(tabID));

  //change the label element that matches the index
  tabHTML.getElementsByClassName("tabLabel")[tabIndex].innerHTML = newString;
}

/**
* Function used to change the label of 
*
* Note: Because this is undocumented, if the HTML changes in future releases then it
* will potentially break this function.
*
* sectionID: the ID of the section
* newString: the new string to use
*/
app.getSharedData().changeSectionTitle = function(sectionID, newString) {

  // gets pointer to the outer div for the section
  var sectionHTML = document.getElementById(app.getSharedData().getFEBObjectID(sectionID));

  //there is only one label element in this html and it is the section header label
  sectionHTML.getElementsByTagName("label")[0].innerHTML = newString;
}

/**
* Changes the column headers in the survey widget.  It searches for all the HTML objects with the 
* classname "question-option-cell" and then changes the "title" attribute of the radio buttons.
*
* Then it gets the widget ID and searches for the classname "rating-title".
* 
* Note: Because this is undocumented, if the HTML changes in future releases then it
* will potentially break this function.
*
* surveyID: the ID of the survey object
* colNum: the column number
* newString: the string to set the column header
*/
app.getSharedData().changeSurveyColumnHeaders = function(pageID, fieldID, surveyID, colNum, newString) {
  
	// need to also change the title of all the items in this column
	//get all the question-option-cell objects
	//loop through them and only change the ones that match the column index?
	//rating-title is another survey option - but we dont have to change the lang for this one
	var qFields = document.getElementsByClassName("question-option-cell");
	
	if(qFields.length > 0) {
		for(var j=0;j<qFields.length;j++) {
			//get the <td> element
			var td = qFields.item(j);
			
			//get the child <input>
			var qInput = td.getElementsByTagName("input"); 
			var qName = get(qInput, 0).name;
			var searchStr = '_option' + colNum.toString();
			if(qName.indexOf(searchStr) != -1) {
				get(qInput, 0).title = newString;
			}
		}
		
	  //change the column titles - get elements by class name
	  var questionList = document.getElementsByClassName(surveyID);
	  var tempItem = get(questionList, 0);
	  var tempQText = tempItem.getElementsByClassName("rating-title");
	  get(tempQText, colNum).innerHTML = newString;
	}
}

/** 
* Sorts the table by PID, FID, index.  The column ID's are hard-coded in this function
* want to pass and array of column ids, the table should be sorted in the order provided
*
* theItem: the Table object to sort
*/
app.getSharedData().sortTable = function(theItem)
{	
	var tblLength = theItem.getLength();
	//build the array with all the columns
  var records = new Array();
  for(var i = 0; i < tblLength; i++) {
    var newObj = {pageID: theItem.get(i).F_TPageID.getValue() , fieldID: theItem.get(i).F_TItemID.getValue(), type: theItem.get(i).F_TItemType.getValue(), index: theItem.get(i).F_TIndex.getValue(),lang: theItem.get(i).F_TLang.getValue(),str: theItem.get(i).F_TLabelText.getValue()};
    set(records, i, newObj);
  }
  
     //sort the list
     
     if(records !== null) {
       records.sort(function(a,b) {       	
       	var pid1 = get(a, 'pageID');
       	var pid2 = get(b, 'pageID');       	
       	
       	var fid1 = get(a, 'fieldID');
       	var fid2 = get(b, 'fieldID');
       	
       	var in1 = get(a, 'index');
       	var in2 = get(b, 'index');
       	
       	//sort by PID
       	if(pid1 !== pid2) {
       		if(pid1 < pid2) return -1;
       		if(pid1 > pid2) return 1;
       		return 0;
       	}
       	
       	//sort by FID
       	if(fid1 !== fid2) {
       		if(fid1 < fid2) return -1;
       		if(fid1 > fid2) return 1;
       		return 0;
       	}
       	
       	//sort by index
       	if(in1 !== in2) {
       		if(in1 < in2) return -1;
       		if(in1 > in2) return 1;
       		return 0;
       	}
       });
       
      //clear the table
      theItem.setValue(new Array());

      //add each record back in
	    for(var j=0;j< records.length;j++) {
	      var row = theItem.createNew();
	      row.F_TPageID.setValue(get(get(records,j), 'pageID'));
	      row.F_TItemID.setValue(get(get(records,j), 'fieldID'));
	      row.F_TItemType.setValue(get(get(records,j), 'type'));
	      row.F_TIndex.setValue(get(get(records,j), 'index'));
        row.F_TLang.setValue(get(get(records,j), 'lang'));
        row.F_TLabelText.setValue(get(get(records,j), 'str'));
	      theItem.add(row);
	    }
     }
}

//check to see if entry exists in the table first
app.getSharedData().checkTableForEntry = function(theTable, pageID, fieldID, lang, label) {

  var entryFound = false;

  for(var i = 0; i < theTable.getLength(); i++) {
  	var row = theTable.get(i);
    if(get(row, 'F_TPageID').getValue() === pageID && get(row, 'F_TItemID').getValue() === fieldID && get(row, 'F_TLang').getValue() === lang && get(row, 'F_TLabelText').getValue() === label) {
      entryFound = true;
      break;
    }
  }
  return entryFound;
}